@@ -1,12 +1,11 @@
-/*
- *  File ergm/src/model.c
- *  Part of the statnet package, http://statnet.org
+/*  File src/model.c in package ergm, part of the Statnet suite
+ *  of packages for network analysis, http://statnet.org .
  *
  *  This software is distributed under the GPL-3 license.  It is free,
- *  open source, and has the attribution requirements (GPL Section 7) in
- *    http://statnet.org/attribution
+ *  open source, and has the attribution requirements (GPL Section 7) at
+ *  http://statnet.org/attribution
  *
- *  Copyright 2012 the statnet development team
+ *  Copyright 2003-2013 Statnet Commons
  */
 #include <string.h>
 #include "model.h"
@@ -20,6 +19,7 @@ void ModelDestroy(Model *m)
 
   for(i=0; i < m->n_terms; i++){
     free(m->dstatarray[i]);
+    free(m->termarray[i].statcache);
   }
   free(m->dstatarray);
   free(m->termarray);
@@ -100,12 +100,6 @@ Model* ModelInitialize (char *fnames, char *sonames, double **inputsp,
       thisterm->s_func = 
 	(void (*)(ModelTerm*, Network*)) R_FindSymbol(fn,sn,NULL);
 
-      /* Optional function for those statistics that care about
-	 duration. Called just before the timer is incremented. */
-      fn[0]='t';
-      thisterm->t_func =
-	(void (*)(ModelTerm*, Network*)) R_FindSymbol(fn,sn,NULL);
-
       /*Clean up by freeing sn and fn*/
       free((void *)fn);
       free((void *)sn);
@@ -131,6 +125,8 @@ Model* ModelInitialize (char *fnames, char *sonames, double **inputsp,
 					       memory, since thisterm->dstats
 					       can be modified but 
 					       m->dstatarray[l] cannot be.  */
+      thisterm->statcache = (double *) malloc(sizeof(double) * thisterm->nstats);
+
       thisterm->ninputparams = (int) *inputs++; /* Set # of inputs */
       /* thisterm->inputparams is a ptr to inputs */
       thisterm->inputparams = (thisterm->ninputparams ==0) ? 0 : inputs; 
@@ -174,25 +170,3 @@ void ChangeStats(unsigned int ntoggles, Vertex *toggletail, Vertex *togglehead,
     dstats += (mtp++)->nstats;
   }
 }
-
-
-/*
-  MCMCChangeStatsT
-  A helper's helper function to compute change statistics associated with advancing the clock by 1 unit.
-  The vector of changes is written to m->workspace.
-*/
-void ChangeStatsT(Network *nwp, Model *m){
-  ModelTerm *mtp = m->termarray;
-  double *dstats = m->workspace;
-  
-  for (unsigned int i=0; i < m->n_terms; i++){
-    /* Calculate change statistics */
-    mtp->dstats = dstats; /* Stuck the change statistic here.*/
-    if(mtp->t_func){
-      (*(mtp->t_func))(mtp, nwp);  /* Call t_??? function */
-    }else{
-      memset(mtp->dstats, 0, mtp->nstats*sizeof(double)); /* If none exists, zero changes. */
-    }
-    dstats += (mtp++)->nstats;
-  }
-}
